package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.resp.THospitalPageResp;
import com.ruoyi.system.mapper.SysUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.THospitalMapper;
import com.ruoyi.system.domain.THospital;
import com.ruoyi.system.service.ITHospitalService;
import org.springframework.util.ObjectUtils;

/**
 * 医院信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@Service
public class THospitalServiceImpl implements ITHospitalService 
{
    @Autowired
    private THospitalMapper tHospitalMapper;

    @Autowired
    private SysUserMapper userMapper;

    /**
     * 查询医院信息
     * 
     * @param id 医院信息主键
     * @return 医院信息
     */
    @Override
    public THospital selectTHospitalById(Long id)
    {
        return tHospitalMapper.selectTHospitalById(id);
    }

    /**
     * 查询医院信息列表
     * 
     * @param tHospital 医院信息
     * @return 医院信息
     */
    @Override
    public List<THospital> selectTHospitalList(THospital tHospital)
    {
        return tHospitalMapper.selectTHospitalList(tHospital);
    }

    /**
     * 新增医院信息
     * 
     * @param tHospital 医院信息
     * @return 结果
     */
    @Override
    public int insertTHospital(THospital tHospital)
    {
        return tHospitalMapper.insertTHospital(tHospital);
    }

    /**
     * 修改医院信息
     * 
     * @param tHospital 医院信息
     * @return 结果
     */
    @Override
    public int updateTHospital(THospital tHospital)
    {
        return tHospitalMapper.updateTHospital(tHospital);
    }

    /**
     * 批量删除医院信息
     * 
     * @param ids 需要删除的医院信息主键
     * @return 结果
     */
    @Override
    public int deleteTHospitalByIds(Long[] ids)
    {
        return tHospitalMapper.deleteTHospitalByIds(ids);
    }

    /**
     * 删除医院信息信息
     * 
     * @param id 医院信息主键
     * @return 结果
     */
    @Override
    public int deleteTHospitalById(Long id)
    {
        return tHospitalMapper.deleteTHospitalById(id);
    }

    @Override
    public List<SysUser> getHosptialAdminList() {
        List<SysUser> userList = userMapper.selectCommonList("common");
        List<THospital> tHospitals = tHospitalMapper.selectTHospitalList(new THospital());
        //过滤出还没有所属医院的管理员
        List<Long> adminIds = tHospitals.stream().map(a -> a.getAdminId()).collect(Collectors.toList());
        if (!ObjectUtils.isEmpty(adminIds)){
            userList = userList.stream().filter(a -> !adminIds.contains(a.getUserId())).collect(Collectors.toList());
        }
        return userList;
    }

    @Override
    public List<THospitalPageResp> queryByPage(THospital tHospital) {
        return tHospitalMapper.queryByPage(tHospital);
    }
}
